On 2020-05-21 Jon Crall gave a TA2 deep dive presentation on kwcoco. These
talks were recorded. And uploaded to girder:

https://data.kitware.com/#collection/602457272fa25629b95d1718/folder/60a8270c2fa25629b98533c6

There is the one from 2020-05-21: https://data.kitware.com/#item/60a836722fa25629b9869bab

There is also a 1-on-1 discussion with Matt Purri: 
https://data.kitware.com/#item/60a82d722fa25629b9854130

Corresponding slides are here: 
https://docs.google.com/presentation/d/1ezxopzQDhfRzUoQ1oSmoAJKSGmAzT3Q4ESgdz52-F-Y/
